# Changelog

## [0.2.1](https://github.com/SongshGeo/twist-academic/compare/v0.2.0...v0.2.1) (2026-03-17)


### Bug Fixes

* **config:** :bug: remove release-as version from release-please configuration ([690171d](https://github.com/SongshGeo/twist-academic/commit/690171dd5f5d7b1d856f8d62b948718b41695b5c))

## [0.2.0](https://github.com/SongshGeo/twist-academic/compare/v0.1.0...v0.2.0) (2026-03-17)


### Features

* **notifications:** :sparkles: add LarkNotifier for webhook notifications and refactor notify system ([f548ea8](https://github.com/SongshGeo/twist-academic/commit/f548ea862fd8b46d8a84fd2ef643c17aaec802ef))
